==> pyside2_vfx_template-0.2.0.tar.gz: pyside2_vfx_template-0.2.0/README.md <==
<p align="left">
  <a href="https://www.python.org">
  <img src="https://img.shields.io/badge/-Python-FFD43B?style=for-the-badge&logo=python" alt="Python"/></a> 
  <img src="https://img.shields.io/badge/-PySide-284821?style=for-the-badge&logo=qt" alt="Python"/></a> 
  <img src="https://img.shields.io/badge/-Windows-00A4EF?style=for-the-badge&logo=windows" alt="Compatible with Windows"/></a>
  <img src="https://img.shields.io/badge/-macOS-000000?style=for-the-badge&logo=apple" alt="Compatible with macOS"/></a>
  <img src="https://img.shields.io/badge/-Linux-E95420?style=for-the-badge&logo=linux" alt="Compatible with Linux"/></a> 
</p>

<div id="top"></div>
<!-- PROJECT LOGO -->
<br />
<div align="center">
  <a href="https://github.com/healkeiser/cloud_vfx_server">
    <img src="https://qt-wiki-uploads.s3.amazonaws.com/images/0/07/PySideLogo1.png" alt="Logo" width="150" >
  </a>

  <h3 align="center">PySide2 VFX Template</h3>

  <p align="center">
    <br />
    <br />
    <br />
  </p>
</div>



<!-- TABLE OF CONTENTS -->
## Table of Contents
<!--ts-->
   * [About](#about)
   * [Installation](#installation)
   * [Example](#example)
   * [Contact](#contact)
<!--te-->



<!-- ABOUT -->
## About

Custom Python classes and utilities tailored for PySide2 built UI, in VFX-oriented DCC applications.

<!-- INSTALLATION -->
## Installation

``` shell
pip install pyside2-vfx-template
```



<!-- EXAMPLE -->
## Example

After installing PySide2 VFX Template, you can run the demo:

``` shell
python example.py
```



<!-- CONTACT -->
## Contact

Project Link: [PySide2 VFX Template](https://github.com/healkeiser/pyside2_vfx_template)

<p align='left'>
  <a href="https://www.linkedin.com/in/valentin-beaumont">
  <img src="https://img.shields.io/badge/-LinkedIn-0A66C2?style=for-the-badge&logo=linkedin" alt="LinkedIn"/></a> 
  <a href="https://www.behance.net/el1ven">
  <img src="https://img.shields.io/badge/-Behance-313131?style=for-the-badge&logo=behance" alt="Behance"/></a> 
  <a href="https://twitter.com/valentinbeaumon">
  <img src="https://img.shields.io/badge/-Twitter-E1E8ED?style=for-the-badge&logo=twitter" alt="Twitter"/></a> 
  <a href="https://www.instagram.com/val.beaumontart">
  <img src="https://img.shields.io/badge/-Instagram-85255b?style=for-the-badge&logo=instagram" alt="Instagram"/></a>
  <a href="https://healkeiser.gumroad.com/subscribe">
  <img src="https://img.shields.io/badge/-Gumroad-20151f?style=for-the-badge&logo=gumroad" alt="Gumroad"/></a>
</p>

[!["Buy Me A Coffee"](https://www.buymeacoffee.com/assets/img/custom_images/yellow_img.png)](https://www.buymeacoffee.com/healkeiser)

==> pyside2_vfx_template-0.5.8.tar.gz: pyside2_vfx_template-0.5.8/README.md <==
<p align="left">
  <a href="https://www.python.org">
  <img src="https://img.shields.io/badge/-Python-FFD43B?style=for-the-badge&logo=python" alt="Python"/></a>
  <img src="https://img.shields.io/badge/-PySide-284821?style=for-the-badge&logo=qt" alt="Python"/></a>
  <img src="https://img.shields.io/badge/-Windows-00A4EF?style=for-the-badge&logo=windows" alt="Compatible with Windows"/></a>
  <img src="https://img.shields.io/badge/-macOS-000000?style=for-the-badge&logo=apple" alt="Compatible with macOS"/></a>
  <img src="https://img.shields.io/badge/-Linux-E95420?style=for-the-badge&logo=linux" alt="Compatible with Linux"/></a>
</p>

<div align="center">

  ![Logo](./docs/images/pyside2_vfx_template_logo_large_dark.svg#gh-light-mode-only)
  ![Logo](./docs/images/pyside2_vfx_template_logo_large_light.svg#gh-dark-mode-only)
  
  <h3 align="center">PySide2 VFX Template</h3>

  <p align="center">
    Custom Python classes and utilities tailored for PySide2 built UI, in VFX-oriented DCC applications.
    <br/>
    <br/>
    <br/>
  </p>

</div>



<!-- TABLE OF CONTENTS -->
## Table of Contents
<!--ts-->
- [PySide2 VFX Template](#pyside2-vfx-template)
  - [Table of Contents](#table-of-contents)
  - [About](#about)
  - [Installation](#installation)
  - [Example](#example)
  - [Documentation](#documentation)
  - [Contact](#contact)
<!--te-->



<!-- ABOUT -->
## About

Custom Python classes and utilities tailored for PySide2 built UI, in VFX-oriented DCC applications.



<!-- INSTALLATION -->
## Installation

``` shell
pip install pyside2-vfx-template
```

> [!IMPORTANT]
> In order to have access to the module, make sure to add `pyside2_vfx_template` to the `$PYTHONPATH` of the DCCs. For Houdini, you can find the [houdini_package file](./houdini_package.json).



<!-- EXAMPLE -->
## Example

After installing PySide2 VFX Template, you can run the demo:

``` shell
python example.py
```
Or:
``` python
from pyside2_vfx_template import example

example.main()
```

Here's how it would like like launched from Houdini:

![Screenshot](./docs/images/LWpoFDJlzh.png)

> [!NOTE]
> As you can see, you can still load the DCC stylesheet if you want, but the toolbar, menu bar and statusbar will remain with a custom stylesheet.



<!-- DOCUMENTATION -->
## Documentation

Please read the full documentation [here](https://healkeiser.github.io/pyside2_vfx_template/).



<!-- CONTACT -->
## Contact

Project Link: [PySide2 VFX Template](https://github.com/healkeiser/pyside2_vfx_template)

<p align='left'>
  <a href="https://www.linkedin.com/in/valentin-beaumont">
  <img src="https://img.shields.io/badge/-LinkedIn-0A66C2?style=for-the-badge&logo=linkedin" alt="LinkedIn"/></a>
  <a href="https://www.behance.net/el1ven">
  <img src="https://img.shields.io/badge/-Behance-313131?style=for-the-badge&logo=behance" alt="Behance"/></a>
  <a href="https://twitter.com/valentinbeaumon">
  <img src="https://img.shields.io/badge/-Twitter-E1E8ED?style=for-the-badge&logo=twitter" alt="Twitter"/></a>
  <a href="https://www.instagram.com/val.beaumontart">
  <img src="https://img.shields.io/badge/-Instagram-85255b?style=for-the-badge&logo=instagram" alt="Instagram"/></a>
  <a href="https://healkeiser.gumroad.com/subscribe">
  <img src="https://img.shields.io/badge/-Gumroad-20151f?style=for-the-badge&logo=gumroad" alt="Gumroad"/></a>
</p>

[!["Buy Me A Coffee"](https://www.buymeacoffee.com/assets/img/custom_images/yellow_img.png)](https://www.buymeacoffee.com/healkeiser)
